<?php


namespace App\RestApi\FiscalDocument\Requests;


use Freelabois\LaravelQuickstart\Traits\RequestValidator;
use Illuminate\Foundation\Http\FormRequest;

class NfstRequest extends FormRequest
{
    use RequestValidator;

    public array $post_rules = [
        'nfst_fk_pes_codigo' => 'required|integer',
        'nfst_cpf_cnpj' => 'required|string|max:15',
        'nfst_ie' => 'required|string|max:15',
        'nfst_razao_social' => 'required|string|max:80',
        'nfst_telefone_contato' => 'required|string|max:15',
        'nfst_end_cep' => 'required|string|max:10',
        'nfst_end_logradouro' => 'required|string|max:80',
        'nfst_end_numero' => 'required|string|max:10',
        'nfst_end_bairro' => 'required|string|max:80',
        'nfst_end_complemento' => 'required|string|max:80',
        'nfst_end_cidade' => 'required|string|max:80',
        'nfst_end_uf' => 'required',
        'nfst_classe_consumo' => 'required|integer',
        'nfst_fase_ou_tipo_utilizacao' => 'required|integer',
        'nfst_grupo_tensao' => 'required|integer',
        'nfst_cod_id_consumidor_assinante' => 'required|string|max:12',
        'nfst_data_emissao' => 'required|string|max:8',
        'nfst_modelo' => 'required|numeric',
        'nfst_serie' => 'required|string|max:3',
        'nfst_numero' => 'required|numeric',
        'nfst_codigo_autenticacao_digital' => 'required|string|max:32',
        'nfst_valor_total' => 'required|numeric',
        'nfst_bc_icms' => 'required|numeric',
        'nfst_icms_destacado' => 'required|numeric',
        'nfst_op_isentas' => 'required|numeric',
        'nfst_outros_valores' => 'required|numeric',
        'nfst_situacao_documento' => 'required',
        'nfst_informacao_adicional' => 'required|string|max:30',
        'nfst_ano_mes_referencia' => 'required|string|max:4',
        'nfst_ref_item_nf' => 'required|numeric',
        'nfst_nro_terminal_ou_uc' => 'required|string|max:12',
        'nfst_tipo_pessoa' => 'required|integer',
        'nfst_tipo_cliente' => 'required|numeric',
        'nfst_subclasse_consumo' => 'required|numeric',
        'nfst_nro_terminal_principal' => 'required|string|max:12',
        'nfst_cnpj_emitente' => 'required|string|max:14',
        'nfst_nro_fat_comercial' => 'required|numeric',
        'nfst_valor_total_fat_comercial' => 'required|string|max:8',
        'nfst_data_leitura_anterior' => 'required|string|max:8',
        'nfst_data_leitura_atual' => 'required|string|max:8',
        'nfst_codigo_aut_digital' => 'required|string|max:32',
        'nfst_data_aut_digital' => 'required|string|max:8',
        'nfst_observacao' => 'required|string|max:50',
        'nfst_usu_insert' => 'required|string|max:30',
        //Validação serviços
        
        'servicos.nfsti_fk_nfst_codigo' => 'integer',
        'servicos.nfsti_nro_ordem' => 'required|numeric',
        'servicos.nfsti_classificacao' => 'required|numeric',
        'servicos.nfsti_cod_referencia' => 'required',
        'servicos.nfsti_fk_cfop_codigo' => 'required|string|max:10',
        'servicos.nfsti_fk_pve_codigo' => 'required|integer',
        'servicos.nfsti_descricao' => 'required|string|max:40',
        'servicos.nfsti_unidade' => 'required|string|max:6',
        'servicos.nfsti_valor_unitario' => 'required|numeric',
        'servicos.nfsti_quantidade' => 'required|numeric',
        'servicos.nfsti_valor_total' => 'required|numeric',
        'servicos.nfsti_bc_icms' => 'required|numeric',
        'servicos.nfsti_aliquota_icms' => 'required|numeric',
        'servicos.nfsti_valor_icms' => 'required|numeric',
        'servicos.nfsti_aliquota_pis' => 'required|numeric',
        'servicos.nfsti_valor_pis' => 'required|numeric',
        'servicos.nfsti_aliquota_cofins' => 'required|numeric',
        'servicos.nfsti_valor_cofins' => 'required|numeric',
        'servicos.nfsti_total_com_tributacao' => 'required|numeric',
        'servicos.nfsti_tributado' => 'required|integer',
        'servicos.nfsti_usu_insert' => 'required|string|max:30'
    ];

    public array $put_rules = [
        // 'pes_nome' => 'required|string|max:80',
        // //Validação do endereço
        // 'address.pee_logradouro' => 'required|string|max:80|nullable',
        // 'address.pee_numero' => 'required|string|max:10|nullable',
        // 'address.pee_bairro' => 'required|string|max:80|nullable',
        // 'address.pee_cep' => 'required|string|max:10|nullable',
        // 'address.pee_pais' => 'required|string|max:30|nullable',
        // 'address.pee_cidade' => 'required|string|max:80|nullable',
        // 'address.pee_uf' => 'required|string|max:2|nullable',
        // 'address.pee_complemento' => 'required|string|max:80|nullable',
        // 'address.pee_latitude' => 'required_with:pee_longitude|numeric|nullable',
        // 'address.pee_longitude' => 'required_with:pee_latitude|numeric|nullable',
        // 'address.pee_fk_tpe_codigo' => 'required|integer|nullable|exists:dynamicdb.cadastro.tipo_endereco,tpe_codigo',
        // //Validação dos dados de contato
        // 'contact.peco_contato' => 'required|string|max:80',
        // 'contact.peco_email' => 'required_without:contact.peco_telefone|string|max:250|email',
        // 'contact.peco_telefone' => 'required_without:contact.peco_email|string|max:15'
    ];

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }


}
