<?php

namespace App\RestApi\ProductionOrder\Controllers;

use App\Http\Controller;
use App\RestApi\ProductionOrder\Requests\StoreProductionOrderRequest;
use App\RestApi\ProductionOrder\Requests\UpdateProductionOrderRequest;
use App\RestApi\ProductionOrder\Requests\ChangeProductionOrderStatus;
use Freelabois\LaravelQuickstart\Traits\Crudable;
use Schaffen\ProductionOrder\ProductionOrder\Managers\ProductionOrderManager;
use Schaffen\ProductionOrder\ProductionOrder\Repositories\ProductionOrderRepository;
use Illuminate\Http\Request;

class ProductionOrderController extends Controller
{
    //
    use Crudable;

    public function __construct(
        ProductionOrderManager $manager,
        ProductionOrderRepository $repository
    )
    {
        $this->setup($manager, $repository);
    }

    public function index(Request $request) {
        $filter = $request->all();
        return $this->manager->index($filter);
    }

    public function store(StoreProductionOrderRequest $request)
    {
        return $this->manager->storeOrUpdate($request->all());
    }

    public function update(UpdateProductionOrderRequest $request, $id)
    {
        return $this->manager->update($request->validated(), $id);
    }

    public function show($id) {
        return $this->manager->show($id);
    }

    public function showHistoric($id) 
    {
        return $this->manager->showHistoric($id);
    }
    
    public function changeStatus(ChangeProductionOrderStatus $request, $id) {
        return $this->manager->changeProductionOrderStatus($request->validated(), $id);
    }

    public function destroy($id) {
        return $this->manager->destroy($id);
    }

    public function batchList($id) {
        return $this->manager->batchList($id);
    }
}
